#Zainstaluj potrzebne pakiety
install.packages("compindexR")
install.packages("readxl")
install.packages("devtools")
install.packages("openxlsx")
install.packages("ggplot2")
#Załaduj potrzebne pakiety
library(compindexR)
library(readxl)
library(devtools)
library(openxlsx)
library(ggplot2)

#Pierwsza kolumna jako nazwa wiersza
x<-data.frame(Syntetyczny,row.names = TRUE)

#Zamiana destymulant na stymulanty
x <- x %>%
  mutate(x7 = 1/x1)

x <- x %>%
  mutate(x8 = 1/x2)

wybrane<-x[3:8]
#Normalizacja zmiennych
y<-scaling(wybrane,method = "min-max")
#Wyzanczenie wartości miernika syntetycznego
calc_average(y, avg_type = "simple") 

#Optymalizacja wag
ci_optimizer(y)
#W przypadku niemożliwości otrzymania założonych wag zredukuj zesstaw zmiennych diagnostycznych o te najbardziej skorelowane
calc_compindex(y, avg_type = "simple",vif_based_calc=TRUE, si_diff = 0.005)
ci_optimizer(y)
#Algorytm optymalizacyjny
si_linear_exc(y, avg_type = "simple")
si_linear_exc_vif(y, avg_type = "simple", vif_threshold = 4.5)
#Wyznaczenie optymalnych wartości
z<-calc_compindex(y, avg_type = "simple",vif_based_calc=TRUE, si_diff = 0.005)
#Zapisanie wartości miernika syntetycznego i rangi 
ranks <- z$ci
#Posorotwanie uzyskanych wyników
ranks_sorted <- ranks[order(ranks$ranks), ]
#Wizualizacja
barplot(ranks_sorted$ci, names.arg = row.names(ranks_sorted), col = "skyblue", main = "Poziom rozwoju sektora ochrony zdrowia", ylab = "Wartość miernika syntetycznego", las = 2)

#Zapisanie danych do pliku
data<-tibble::rownames_to_column(ranks, "Country")
write.xlsx(data, "lista.xlsx")

#Analiza dla kolejnego roku
x2<-data.frame(Syntetyczny2010,row.names = TRUE)
x2 <- x2 %>%
  mutate(x7 = 1/x1)

wybrane2<-x2[3:7]

y2<-scaling(wybrane2,method = "min-max")
calc_average(y2, avg_type = "simple") 
ci_optimizer(y2)
calc_compindex(y2, avg_type = "simple",vif_based_calc=TRUE, si_diff = 0.005)
ci_optimizer(y2)
si_linear_exc(y2, avg_type = "simple")
si_linear_exc_vif(y2, avg_type = "simple", vif_threshold = 4.5)
z2<-calc_compindex(y2, avg_type = "simple",vif_based_calc=TRUE, si_diff = 0.005)
ranks2 <- z2$ci
ranks_sorted2 <- ranks2[order(ranks2$ranks), ]
data2<-tibble::rownames_to_column(ranks2, "Country")

#Złączenie danych z obu analizowanych lat
merged_data <- merge(data, data2, by = "Country")
#Sprawdzenie zgodności uporządkowań
kendall_test <- cor.test(merged_data$ranks.x, merged_data$ranks.y, method = "kendall")
#Prezenetacja wartości wsp. tau Kendalla i odpowiadającej mu p-value
print(paste("Kendall's Tau:", kendall_tau))
print(paste("P-value:", kendall_test$p.value))

merged_data <- merged_data %>%
  mutate(roznica = ci.y - ci.x)

ggplot(merged_data, aes(x = reorder(Country, -roznica), y = roznica, color = ifelse(roznica >= 0, "green", "red"))) +
  geom_point(size = 3) +
  scale_color_identity() +
  geom_hline(yintercept = 0, linetype = "solid", color = "black", size = 0.2) + 
  labs(title = "Zmiana wartości miernika syntetycznego", x = "Kraje UE", y = "Różnica") +
  theme_minimal() +
  theme(axis.text.x = element_text(angle = 45, hjust = 1))